@@ -4,6 +4,7 @@ tm1_get_cube_dimensions <- function(tm1_connection, cube) {
   tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
   tm1_ssl <- tm1_connection$ssl
+  tm1_base_url <- tm1_connection$base_url
 
   # added because some http does not know space
   cube <- gsub(" ", "%20", cube, fixed=TRUE)
@@ -14,13 +15,14 @@ tm1_get_cube_dimensions <- function(tm1_connection, cube) {
   u2 <- tm1_adminhost
   u3 <- ":"
   u4 <- tm1_httpport
-  u5 <- "/api/v1/Cubes('"
-  u6 <- cube
-  u7 <- "')/Dimensions"
+  u5 <- "/"
+  u6 <- "api/v1/Cubes('"
+  u7 <- cube
+  u8 <- "')/Dimensions"
 
 
   # url development
-  url <- paste0(u1, u2, u3, u4, u5, u6, u7)
+  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8), paste0(tm1_base_url, u6, u7, u8))
   #url = "https://localhost:8881/api/v1/Cubes('SalesCube')/Dimensions"
 
   # post request
