@@ -4,6 +4,7 @@ tm1_get_dimension_attributes <- function(tm1_connection, dimension) {
   tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
   tm1_ssl <- tm1_connection$ssl
+  tm1_base_url <- tm1_connection$base_url
 
   # added because some http does not know space
   dimension <- gsub(" ", "%20", dimension, fixed=TRUE)
@@ -13,14 +14,15 @@ tm1_get_dimension_attributes <- function(tm1_connection, dimension) {
   u2 <- tm1_adminhost
   u3 <- ":"
   u4 <- tm1_httpport
-  u5 <- "/api/v1/Dimensions('"
-  u6 <- dimension
-  u7 <- "')/Hierarchies('"
-  u8 <- dimension
-  u9 <- "')/ElementAttributes"
+  u5 <- "/"
+  u6 <- "api/v1/Dimensions('"
+  u7 <- dimension
+  u8 <- "')/Hierarchies('"
+  u9 <- dimension
+  u10 <- "')/ElementAttributes"
 
   # url development
-  url <- paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9)
+  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10), paste0(tm1_base_url, u6, u7, u8, u9, u10))
   #url = "https://localhost:8881/api/v1/Dimensions('Account1')/Hierarchies('Account1')/ElementAttributes
 
   # post request
