@@ -4,6 +4,7 @@ tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsCo
   tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
   tm1_ssl <- tm1_connection$ssl
+  tm1_base_url <- tm1_connection$base_url
 
   # added because some http does not know space
   cube <- gsub(" ", "%20", cube, fixed=TRUE)
@@ -15,15 +16,16 @@ tm1_get_native_view <- function(tm1_connection, cube="", view="", RowElementAsCo
   u2 <- tm1_adminhost
   u3 <- ":"
   u4 <- tm1_httpport
-  u5 <- "/api/v1/Cubes('"
-  u6 <- cube
-  u7 <- "')/Views('"
-  u8 <- view
-  u9 <- "')/tm1.Execute"
-  u10 <- "?$expand=Axes($expand=Tuples($expand=Members($select=Name,UniqueName))),Cells($select=Value)"
+  u5 <- "/"
+  u6 <- "api/v1/Cubes('"
+  u7 <- cube
+  u8 <- "')/Views('"
+  u9 <- view
+  u10 <- "')/tm1.Execute"
+  u11 <- "?$expand=Axes($expand=Tuples($expand=Members($select=Name,UniqueName))),Cells($select=Value)"
 
 
-  url <- paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10)
+  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10, u11), paste0(tm1_base_url, u6, u7, u8, u9, u10, u11))
   #url = "https://localhost:8881/api/v1/Cubes('{{cubeName}}')/Views('{{viewName}}')/tm1.Execute
   #?$expand=Axes($expand=Tuples($expand=Members($select=Name))),Cells($select=Value)"
 
