@@ -4,16 +4,18 @@ tm1_logout <- function(tm1_connection) {
   tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
   tm1_ssl <- tm1_connection$ssl
+  tm1_base_url <- tm1_connection$base_url
 
   u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
   #u1 <- "https://"
   u2 <- tm1_adminhost
   u3 <- ":"
   u4 <- tm1_httpport
-  u5 <- "/api/logout"
+  u5 <- "/"
+  u6 <- "api/logout"
 
   # url development
-  url <- paste0(u1, u2, u3, u4, u5)
+  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6), paste0(tm1_base_url, u6))
   #url = "https://localhost:8881/api/v1/Configuration"
 
   # post request
